.. a documentation master file, created by
   sphinx-quickstart on Wed Dec 19 18:34:22 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

``APRSD`` Documentation
=======================

.. include:: readme.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   changelog
   install
   configure
   server
   plugin

   apidoc/modules.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. include:: links.rst
